(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     29896,        731]
NotebookOptionsPosition[     30286,        721]
NotebookOutlinePosition[     30751,        741]
CellTagsIndexPosition[     30708,        738]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Method of Sections\n",
 StyleBox["Zhelong He, Marek-Jerzy Pindera \nUniversity of Virginia, \
2017-10-07",
  FontSize->16,
  FontColor->GrayLevel[0]]
}], "Title",
 TextAlignment->Center],

Cell[TextData[{
 "When we need to find the force in only a few members of a truss, we can \
analyze the truss using the method of sections. It is based on the principle \
that if the truss is in equilibrium then any segment of the truss is also in \
equilibrium.\nSince we only have three independent equilibrium equations, \
i.e. 2 force components equilibrium + 1 moment equilibrium, or 1 force \
components equilibrium + 2 moment equilibrium, we should try to choose \
section passes no more than 3 members. \nAlways assume that the unknown \
member forces at the cut section are tensile forces, i.e., \
\[OpenCurlyDoubleQuote]pulling\[CloseCurlyDoubleQuote] on the member. By \
doing this, the numerical solution of the equilibrium equations will yield \
positive scalars for members in tension and negative scalars for members in \
compression.\nWe pick an example from the textbook in chapter 6.4 to show the \
process in details. During the solution, we should carefully consider ways of \
writing the equations so as to yield a direct solution for each of the \
unknowns, rather than having to solve simultaneous equations. So, in this \
example, we first sum moments about G thus yield a direct solution for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "BC"], TraditionalForm]]],
 ", since ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "GC"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "GF"], TraditionalForm]]],
 " create zero moment about G. Then ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "GC"], TraditionalForm]]],
 " and be found directly by the force summation in y direction since ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "BC"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "GF"], TraditionalForm]]],
 " has no component in y direction. Finally, by summing moments about C we \
get ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "GF"], TraditionalForm]]],
 " directly since ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "BC"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "GC"], TraditionalForm]]],
 " create zero moment about C.\nSuch method of section is very quick. As a \
comparison, if the method of joints were used to determine, say, the force in \
member GC, it would be necessary to analyze joints A, B, and G in sequence, \
which is more tedious. "
}], "Text"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`F$$ = 1.07, $CellContext`opt$$ = 
    0, $CellContext`size$$ = 1, $CellContext`\[Alpha]d$$ = 90, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`size$$], 1, 
       Text[
        Style["Plot Range", 12]]}, {1, 2, 5, 10}}, {{
       Hold[$CellContext`opt$$], 0, ""}, {0 -> Text[
         Style["Truss", 12]], 1 -> Text[
         Style["Cut in sections", 12]], 2 -> Text[
         Style[
          Subscript["F", "BC"], 12, Italic]], 3 -> Text[
         Style[
          Subscript["F", "GC"], 12, Italic]], 4 -> Text[
         Style[
          Subscript["F", "GF"], 12, Italic]]}}, {{
       Hold[$CellContext`F$$], 1, 
       Text[
        Style["Load", 12]]}, 0, 10, 0.01}, {{
       Hold[$CellContext`\[Alpha]d$$], 90, 
       Text[
        Style["Direction \[Alpha] / \[Degree]", 12]]}, 19, 198, 1}, {
      Hold[
       Column[{
         Row[{
           Manipulate`Place[1], 
           Spacer[58], 
           Manipulate`Place[2]}], 
         Row[{
           Manipulate`Place[3], 
           Spacer[30], 
           Manipulate`Place[4]}]}]], Manipulate`Dump`ThisIsNotAControl}}, 
    Typeset`size$$ = {750., {235., 244.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`size$30240$$ = 0, $CellContext`opt$30241$$ = 
    False, $CellContext`F$30242$$ = 0, $CellContext`\[Alpha]d$30243$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`F$$ = 1, $CellContext`opt$$ = 
        0, $CellContext`size$$ = 1, $CellContext`\[Alpha]d$$ = 90}, 
      "ControllerVariables" :> {
        Hold[$CellContext`size$$, $CellContext`size$30240$$, 0], 
        Hold[$CellContext`opt$$, $CellContext`opt$30241$$, False], 
        Hold[$CellContext`F$$, $CellContext`F$30242$$, 0], 
        Hold[$CellContext`\[Alpha]d$$, $CellContext`\[Alpha]d$30243$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`w$, $CellContext`h$, $CellContext`\[Theta]$, \
$CellContext`\[Delta]$, $CellContext`\[Alpha]$, $CellContext`sol$, \
$CellContext`RA$, $CellContext`RE$, $CellContext`F1$, $CellContext`F2$, \
$CellContext`F3$, $CellContext`F4$, $CellContext`F5$, $CellContext`F6$, \
$CellContext`F7$, $CellContext`opa1$, $CellContext`opa2$, $CellContext`opa3$, \
$CellContext`truss$, $CellContext`fbd$, $CellContext`FBC$, $CellContext`FGC$, \
$CellContext`FGF$, $CellContext`fbc$, $CellContext`fgc$, $CellContext`fgf$, \
$CellContext`calculatemoment$, $CellContext`Xforcebalance$, \
$CellContext`Yforcebalance$, $CellContext`solved$, \
$CellContext`fullstructure$, $CellContext`partialstructure$, \
$CellContext`jointA$, $CellContext`jointB$, $CellContext`jointC$, \
$CellContext`jointD$, $CellContext`jointssolved$, $CellContext`equations$, \
$CellContext`instruction$, $CellContext`font$}, $CellContext`w$ = 
         2 $CellContext`size$$; $CellContext`h$ = $CellContext`w$ 
          Tan[$CellContext`\[Theta]$]; $CellContext`\[Theta]$ = 
         Pi/4; $CellContext`\[Delta]$ = 0.25 $CellContext`h$; $CellContext`r = 
         0.05 $CellContext`w$; $CellContext`\[Alpha]$ = \
($CellContext`\[Alpha]d$$/180) Pi; $CellContext`font$ = 14; $CellContext`sol$ = 
         Quiet[
           Part[
            Solve[
             
             N[{((-$CellContext`F$$) $CellContext`w$) 
                 Sin[$CellContext`\[Alpha]$] + $CellContext`Fbc \
$CellContext`h$ == 
               0, (-$CellContext`F$$) 
                 Sin[$CellContext`\[Alpha]$] + $CellContext`Fgc 
                 Sin[$CellContext`\[Theta]$] == 
               0, ((-$CellContext`F$$) 
                  Cos[$CellContext`\[Alpha]$]) $CellContext`h$ + \
(($CellContext`F$$ Sin[$CellContext`\[Alpha]$]) 
                  2) $CellContext`w$ + $CellContext`Fgf $CellContext`h$ == 
               0}], {$CellContext`Fbc, $CellContext`Fgc, $CellContext`Fgf}], 
            1]]; $CellContext`fbc$ = 
         ReplaceAll[$CellContext`Fbc, $CellContext`sol$]; $CellContext`fgc$ = 
         ReplaceAll[$CellContext`Fgc, $CellContext`sol$]; $CellContext`fgf$ = 
         ReplaceAll[$CellContext`Fgf, $CellContext`sol$]; $CellContext`opa1$ = 
         If[
           Or[$CellContext`opt$$ == 3, $CellContext`opt$$ == 4], 0.2, 
           1]; $CellContext`opa2$ = If[
           Or[$CellContext`opt$$ == 2, $CellContext`opt$$ == 4], 0.2, 
           1]; $CellContext`opa3$ = If[
           Or[$CellContext`opt$$ == 2, $CellContext`opt$$ == 3], 0.2, 
           1]; $CellContext`colBC = 
         If[$CellContext`opt$$ == 2, Red, Black]; $CellContext`colGC = 
         If[$CellContext`opt$$ == 3, Red, Black]; $CellContext`colGF = 
         If[$CellContext`opt$$ == 4, Red, Black]; $CellContext`truss$ = {
           Apply[{
             CapForm["Round"], 
             Thickness[#], #2, 
             
             Line[{{0, 0}, {$CellContext`w$, $CellContext`h$}, {
               3 $CellContext`w$, $CellContext`h$}, {3 $CellContext`w$, 0}, {
               0, 0}}], 
             Line[{{$CellContext`w$, $CellContext`h$}, {$CellContext`w$, 0}}], 
             
             Line[{{$CellContext`w$, 0}, {
               2 $CellContext`w$, $CellContext`h$}}], 
             
             Line[{{2 $CellContext`w$, $CellContext`h$}, {
               2 $CellContext`w$, 0}}], 
             
             Line[{{2 $CellContext`w$, 0}, {
               3 $CellContext`w$, $CellContext`h$}}]}& , {{0.022, Black}, {
             0.015, 
              GrayLevel[0.6]}}, {1}], {
            GrayLevel[0.7], 
            
            Disk[{3 $CellContext`w$ + 0.18 $CellContext`size$$, 
              0}, $CellContext`r], 
            Thickness[0.005], 
            
            Line[{{3 $CellContext`w$ + 
               0.18 $CellContext`size$$ + $CellContext`r, 2 $CellContext`r}, {
              3 $CellContext`w$ + 
               0.18 $CellContext`size$$ + $CellContext`r, (-2) \
$CellContext`r}}], 
            Line[
             
             Table[{{3 $CellContext`w$ + 
                0.2 $CellContext`size$$ + $CellContext`r, 
                2 $CellContext`r - $CellContext`k $CellContext`size$$}, {
               3 $CellContext`w$ + 
                0.2 $CellContext`size$$ + $CellContext`r + (0.1 
                  Cos[Pi/6]) $CellContext`size$$, 
                2 $CellContext`r - (0.1 
                 Sin[Pi/6]) $CellContext`size$$ - $CellContext`k \
$CellContext`size$$}}, {$CellContext`k, 0, 0.42, 0.08}]]}, {
            GrayLevel[0.7], 
            Disk[{3 $CellContext`w$, $CellContext`h$}, 0.8 $CellContext`r], 
            
            Polygon[{{
              3 $CellContext`w$ - (0.8 $CellContext`r) 
               Sin[Pi/6], $CellContext`h$ + (0.8 $CellContext`r) Cos[Pi/6]}, {
              3 $CellContext`w$ - (0.8 $CellContext`r) 
               Sin[Pi/6] + (4 $CellContext`r) 
                Cos[Pi/6], $CellContext`h$ + (0.8 $CellContext`r) 
                Cos[Pi/6] + (4 $CellContext`r) Sin[Pi/6]}, {
              3 $CellContext`w$ - (0.8 $CellContext`r) 
               Sin[Pi/6] + (4 $CellContext`r) Cos[Pi/6], $CellContext`h$ - (
                0.8 $CellContext`r) Cos[Pi/6] - (4 $CellContext`r) 
               Sin[Pi/6]}, {
              3 $CellContext`w$ - (0.8 $CellContext`r) 
               Sin[Pi/6], $CellContext`h$ - (0.8 $CellContext`r) Cos[Pi/6]}}], 
            Thickness[0.005], 
            
            Line[{{3 $CellContext`w$ - (0.8 $CellContext`r) 
               Sin[Pi/6] + (4 $CellContext`r) 
                Cos[Pi/6], $CellContext`h$ + (0.8 $CellContext`r) 
                Cos[Pi/6] + (4 $CellContext`r) Sin[Pi/6] + $CellContext`r}, {
              3 $CellContext`w$ - (0.8 $CellContext`r) 
               Sin[Pi/6] + (4 $CellContext`r) Cos[Pi/6], $CellContext`h$ - (
                0.8 $CellContext`r) Cos[Pi/6] - (4 $CellContext`r) 
               Sin[Pi/6] - $CellContext`r}}], 
            Line[
             
             Table[{{3 $CellContext`w$ - (0.8 $CellContext`r) 
                Sin[Pi/6] + (4 $CellContext`r) Cos[Pi/6] + 
                0.02 $CellContext`size$$, $CellContext`h$ + (
                  0.8 $CellContext`r) Cos[Pi/6] + (4 $CellContext`r) 
                 Sin[Pi/6] + $CellContext`r - $CellContext`k \
$CellContext`size$$}, {
               3 $CellContext`w$ - (0.8 $CellContext`r) 
                Sin[Pi/6] + (4 $CellContext`r) 
                 Cos[Pi/6] + (0.1 Cos[Pi/6]) $CellContext`size$$ + 
                0.02 $CellContext`size$$, $CellContext`h$ + (
                  0.8 $CellContext`r) Cos[Pi/6] + (4 $CellContext`r) 
                 Sin[Pi/6] + $CellContext`r - (0.1 
                 Sin[Pi/6]) $CellContext`size$$ - $CellContext`k \
$CellContext`size$$}}, {$CellContext`k, 0, 0.75, 0.08}]]}, 
           Map[{
             PointSize[0.015], 
             Point[#], White, 
             PointSize[0.01], 
             Point[#]}& , {{0, 0}, {$CellContext`w$, 0}, {
             2 $CellContext`w$, 0}, {
             3 $CellContext`w$, 0}, {$CellContext`w$, $CellContext`h$}, {
             2 $CellContext`w$, $CellContext`h$}, {
             3 $CellContext`w$, $CellContext`h$}}], {
            Opacity[
             Boole[$CellContext`F$$ != 0]], Blue, 
            Thickness[0.004], 
            Arrowheads[0.03], 
            
            Arrow[{{0, 
              0}, {(-$CellContext`F$$) 
               Cos[$CellContext`\[Alpha]$], (-$CellContext`F$$) 
               Sin[$CellContext`\[Alpha]$]}}], 
            Text[
             Style[
             "F", 15, Italic, Bold], {(-$CellContext`F$$) 
              Cos[$CellContext`\[Alpha]$], (-$CellContext`F$$) 
               Sin[$CellContext`\[Alpha]$] - 0.1 $CellContext`h$}], Black, 
            Thickness[0.002], Dashed, 
            
            Circle[{0, 0}, 0.2 $CellContext`h$, {
             Pi, Pi + $CellContext`\[Alpha]$}], 
            Line[{{0, 0}, {(-0.25) $CellContext`h$, 0}}]}, {
            Text[
             Style[
             "A", 15, Italic, Bold], {(-0.15) $CellContext`h$, 
              0.15 $CellContext`h$}], 
            Text[
             Style[
             "B", 15, Italic, Bold], {$CellContext`w$, 1.15 $CellContext`h$}], 
            Text[
             Style["C", 15, Italic, Bold], {
             2 $CellContext`w$, 1.15 $CellContext`h$}], 
            Text[
             Style["D", 15, Italic, Bold], {
             3 $CellContext`w$, 1.15 $CellContext`h$}], 
            Text[
             Style["E", 15, Italic, Bold], {
             3 $CellContext`w$, (-0.15) $CellContext`h$}], 
            Text[
             Style["F", 15, Italic, Bold], {
             2 $CellContext`w$, (-0.15) $CellContext`h$}], 
            Text[
             Style[
             "G", 15, Italic, 
              Bold], {$CellContext`w$, (-0.15) $CellContext`h$}]}, {
            Opacity[
             Boole[$CellContext`opt$$ == 0]], Black, 
            Thickness[0.002], 
            
            Line[{{0, (-0.25) $CellContext`h$}, {
              0, (-0.45) $CellContext`h$}}], 
            
            Line[{{$CellContext`w$, (-0.25) $CellContext`h$}, \
{$CellContext`w$, (-0.45) $CellContext`h$}}], 
            
            Line[{{2 $CellContext`w$, (-0.25) $CellContext`h$}, {
              2 $CellContext`w$, (-0.45) $CellContext`h$}}], 
            
            Line[{{3 $CellContext`w$, (-0.25) $CellContext`h$}, {
              3 $CellContext`w$, (-0.45) $CellContext`h$}}], 
            Line[{{3.25 $CellContext`w$, 0}, {3.45 $CellContext`w$, 0}}], 
            
            Line[{{3.25 $CellContext`w$, $CellContext`h$}, {
              3.45 $CellContext`w$, $CellContext`h$}}], 
            Arrowheads[{-0.02, 0.02}], 
            
            Arrow[{{0, (-0.3) $CellContext`h$}, {$CellContext`w$, (-0.3) \
$CellContext`h$}}], 
            
            Arrow[{{$CellContext`w$, (-0.3) $CellContext`h$}, {
              2 $CellContext`w$, (-0.3) $CellContext`h$}}], 
            
            Arrow[{{2 $CellContext`w$, (-0.3) $CellContext`h$}, {
              3 $CellContext`w$, (-0.3) $CellContext`h$}}], 
            
            Arrow[{{3.35 $CellContext`w$, 0}, {
              3.35 $CellContext`w$, $CellContext`h$}}], 
            Text[
             Style["2 m", 15, Italic, Bold], {
             0.5 $CellContext`w$, (-0.4) $CellContext`h$}], 
            Text[
             Style["2 m", 15, Italic, Bold], {
             1.5 $CellContext`w$, (-0.4) $CellContext`h$}], 
            Text[
             Style["2 m", 15, Italic, Bold], {
             2.5 $CellContext`w$, (-0.4) $CellContext`h$}], 
            Text[
             Style["2 m", 15, Italic, Bold], {
             3.5 $CellContext`w$, 
              0.5 $CellContext`h$}]}}; $CellContext`fbd$ = {{White, 
            Rectangle[{1.5 $CellContext`w$, -$CellContext`h$}, {
             3.7 $CellContext`w$, 2 $CellContext`h$}], Black, 
            Text[
             Style["C", 15, Italic, Bold], {
             2 $CellContext`w$, 1.15 $CellContext`h$}], 
            Text[
             Style["F", 15, Italic, Bold], {
             2 $CellContext`w$, (-0.15) $CellContext`h$}]}, {Dashed, Black, 
            Thickness[0.004], 
            Arrowheads[0.03], 
            
            Line[{{1.5 $CellContext`w$, $CellContext`h$}, {
              2. $CellContext`w$, $CellContext`h$}}], 
            Dashing[{}], $CellContext`colBC, 
            
            Arrow[{{1.5 $CellContext`w$, $CellContext`h$}, {
              1.8 $CellContext`w$, $CellContext`h$}}], 
            Text[
             Style[
              Subscript["F", "BC"], 15, Italic, Bold], {
             1.75 $CellContext`w$, 1.15 $CellContext`h$}]}, {Dashed, Black, 
            Thickness[0.004], 
            Arrowheads[0.03], 
            
            Line[{{1.5 $CellContext`w$, (
                1.5 $CellContext`w$ - $CellContext`w$) 
               Tan[$CellContext`\[Theta]$]}, {
              2. $CellContext`w$, $CellContext`h$}}], 
            Dashing[{}], $CellContext`colGC, 
            
            Arrow[{{1.5 $CellContext`w$, (
                1.5 $CellContext`w$ - $CellContext`w$) 
               Tan[$CellContext`\[Theta]$]}, {
              1.8 $CellContext`w$, (1.8 $CellContext`w$ - $CellContext`w$) 
               Tan[$CellContext`\[Theta]$]}}], 
            Text[
             Style[
              Subscript["F", "GC"], 15, Italic, Bold], {
             1.75 $CellContext`w$, ((1.75 $CellContext`w$ - $CellContext`w$) 
               Tan[$CellContext`\[Theta]$]) 0.7}]}, {Dashed, Black, 
            Thickness[0.004], 
            Arrowheads[0.03], 
            Line[{{1.5 $CellContext`w$, 0}, {2. $CellContext`w$, 0}}], 
            Dashing[{}], $CellContext`colGF, 
            Arrow[{{1.5 $CellContext`w$, 0}, {1.8 $CellContext`w$, 0}}], 
            Text[
             Style[
              Subscript["F", "GF"], 15, Italic, Bold], {
             
             1.75 $CellContext`w$, (-0.15) $CellContext`h$}]}}; \
$CellContext`FBC$ = {Red, 
           
           Disk[{$CellContext`w$, 0}, 
            0.08 $CellContext`size$$]}; $CellContext`FGF$ = {Red, 
           
           Disk[{2 $CellContext`w$, $CellContext`h$}, 
            0.08 $CellContext`size$$]}; $CellContext`instruction$ = Text[
           Style[
            Switch[$CellContext`opt$$, 0, 
             Column[{
               Text[
                Style[
                "If only the forces in several members are desired,", \
$CellContext`font$, Italic]], 
               Text[
                Style[
                "method of section gives us a quick and direct way", \
$CellContext`font$, Italic]]}], 1, 
             Column[{
               Text[
                Style[
                "Suppose forces in the members BC, GC and GF are desired,", \
$CellContext`font$, Italic]], 
               Text[
                Style[
                "so we choose a section passes these members", \
$CellContext`font$, Italic]]}], 2, 
             Column[{
               Row[{
                 Text[
                  Style["\[Sum]", $CellContext`font$, Italic]], 
                 Spacer[1], 
                 Text[
                  Style[
                   Subscript["M", "G"], $CellContext`font$, Italic]], 
                 Spacer[4], 
                 Text[
                  Style["=", $CellContext`font$]], 
                 Spacer[4], 
                 Text[
                  Style["0", $CellContext`font$, Italic]], 
                 Spacer[4], 
                 Text[
                  Style["=", $CellContext`font$]], 
                 Spacer[4], 
                 Text[
                  Style[
                   Subscript["F", "BC"], $CellContext`font$, Italic]], 
                 Spacer[2], 
                 Text[
                  Style[
                   Subscript["l", "BG"], $CellContext`font$, Italic]], 
                 Spacer[4], 
                 Text[
                  Style["-", $CellContext`font$]], 
                 Spacer[4], 
                 Text[
                  Style["F", $CellContext`font$, Italic]], 
                 Spacer[2], 
                 Text[
                  Style[
                   Subscript["l", "AG"], $CellContext`font$, Italic]], 
                 Spacer[2], 
                 Text[
                  Style["sin \[Alpha]", $CellContext`font$, Italic]]}], 
               Row[{
                 Text[
                  Style[
                   Subscript["F", "BC"], $CellContext`font$, Italic]], 
                 Spacer[4], 
                 Text[
                  Style["=", $CellContext`font$]], 
                 Spacer[4], 
                 Text[
                  Style[
                   NumberForm[$CellContext`fbc$, {4, 2}], $CellContext`font$, 
                   Italic]]}], 
               If[$CellContext`fbc$ > 0, 
                Text[
                 Style[
                 "Member BC is in tension", $CellContext`font$, Italic]], 
                If[$CellContext`fbc$ < 0, 
                 Text[
                  Style[
                  "Member BC is in compression", $CellContext`font$, 
                   Italic]]]]}], 3, 
             Column[{
               Row[{
                 Text[
                  Style["\[Sum]", $CellContext`font$, Italic]], 
                 Spacer[1], 
                 Text[
                  Style[
                   Subscript["F", "y"], $CellContext`font$, Italic]], 
                 Spacer[4], 
                 Text[
                  Style["=", $CellContext`font$]], 
                 Spacer[4], 
                 Text[
                  Style["0", $CellContext`font$, Italic]], 
                 Spacer[4], 
                 Text[
                  Style["=", $CellContext`font$]], 
                 Spacer[4], 
                 Text[
                  Style[
                   Subscript["F", "GC"], $CellContext`font$, Italic]], 
                 Spacer[2], 
                 Text[
                  Style["sin 45\[Degree]", $CellContext`font$, Italic]], 
                 Spacer[4], 
                 Text[
                  Style["-", $CellContext`font$]], 
                 Spacer[4], 
                 Text[
                  Style["F", $CellContext`font$, Italic]], 
                 Spacer[2], 
                 Text[
                  Style["sin \[Alpha]", $CellContext`font$, Italic]], 
                 Spacer[4], 
                 Text[
                  Style["=", $CellContext`font$]], 
                 Spacer[4], 
                 Text[
                  Style["0", $CellContext`font$, Italic]]}], 
               Row[{
                 Text[
                  Style[
                   Subscript["F", "GC"], $CellContext`font$, Italic]], 
                 Spacer[4], 
                 Text[
                  Style["=", $CellContext`font$]], 
                 Spacer[4], 
                 Text[
                  Style[
                   NumberForm[$CellContext`fgc$, {4, 2}], $CellContext`font$, 
                   Italic]]}], 
               If[$CellContext`fgc$ > 0, 
                Text[
                 Style[
                 "Member GC is in tension", $CellContext`font$, Italic]], 
                If[$CellContext`fgc$ < 0, 
                 Text[
                  Style[
                  "Member GC is in compression", $CellContext`font$, 
                   Italic]]]]}], 4, 
             Column[{
               Row[{
                 Text[
                  Style["\[Sum]", $CellContext`font$, Italic]], 
                 Spacer[1], 
                 Text[
                  Style[
                   Subscript["M", "C"], $CellContext`font$, Italic]], 
                 Spacer[4], 
                 Text[
                  Style["=", $CellContext`font$]], 
                 Spacer[4], 
                 Text[
                  Style["0", $CellContext`font$, Italic]], 
                 Spacer[4], 
                 Text[
                  Style["=", $CellContext`font$]], 
                 Spacer[4], 
                 Text[
                  Style["F", $CellContext`font$, Italic]], 
                 Spacer[2], 
                 Text[
                  Style["sin \[Alpha]", $CellContext`font$, Italic]], 
                 Spacer[2], 
                 Text[
                  Style[
                   Subscript["l", "AF"], $CellContext`font$, Italic]], 
                 Spacer[4], 
                 Text[
                  Style["-", $CellContext`font$]], 
                 Spacer[4], 
                 Text[
                  Style["F", $CellContext`font$, Italic]], 
                 Spacer[2], 
                 Text[
                  Style["cos \[Alpha]", $CellContext`font$, Italic]], 
                 Spacer[2], 
                 Text[
                  Style[
                   Subscript["l", "CF"], $CellContext`font$, Italic]], 
                 Spacer[4], 
                 Text[
                  Style["+", $CellContext`font$]], 
                 Spacer[4], 
                 Text[
                  Style[
                   Subscript["F", "GF"], $CellContext`font$, Italic]], 
                 Spacer[2], 
                 Text[
                  Style[
                   Subscript["l", "CF"], $CellContext`font$, Italic]]}], 
               Row[{
                 Text[
                  Style[
                   Subscript["F", "GF"], $CellContext`font$, Italic]], 
                 Spacer[4], 
                 Text[
                  Style["=", $CellContext`font$]], 
                 Spacer[4], 
                 Text[
                  Style[
                   NumberForm[$CellContext`fgf$, {4, 2}], $CellContext`font$, 
                   Italic]]}], 
               If[$CellContext`fgf$ > 0, 
                Text[
                 Style[
                 "Member GF is in tension", $CellContext`font$, Italic]], 
                If[$CellContext`fgf$ < 0, 
                 Text[
                  Style[
                  "Member GF is in compression", $CellContext`font$, 
                   Italic]]]]}]]], {1.35 $CellContext`w$, -$CellContext`h$}]; 
        Graphics[
          
          Switch[$CellContext`opt$$, 
           0, {$CellContext`truss$, $CellContext`instruction$}, 
           1, {$CellContext`truss$, $CellContext`fbd$, \
$CellContext`instruction$}, 
           2, {$CellContext`truss$, $CellContext`fbd$, $CellContext`FBC$, \
$CellContext`instruction$}, 
           3, {$CellContext`truss$, $CellContext`fbd$, \
$CellContext`instruction$}, 
           4, {$CellContext`truss$, $CellContext`fbd$, $CellContext`FGF$, \
$CellContext`instruction$}], 
          PlotRange -> {{-$CellContext`w$, 
             3.7 $CellContext`w$}, {(-1.5) $CellContext`h$, 
             1.5 $CellContext`h$}}, ImageSize -> 500]], 
      "Specifications" :> {{{$CellContext`size$$, 1, 
          Text[
           Style["Plot Range", 12]]}, {1, 2, 5, 10}, ImageSize -> Tiny, 
         ControlType -> Setter, ControlPlacement -> 
         1}, {{$CellContext`opt$$, 0, ""}, {0 -> Text[
            Style["Truss", 12]], 1 -> Text[
            Style["Cut in sections", 12]], 2 -> Text[
            Style[
             Subscript["F", "BC"], 12, Italic]], 3 -> Text[
            Style[
             Subscript["F", "GC"], 12, Italic]], 4 -> Text[
            Style[
             Subscript["F", "GF"], 12, Italic]]}, ControlType -> PopupMenu, 
         ControlPlacement -> 2}, {{$CellContext`F$$, 1, 
          Text[
           Style["Load", 12]]}, 0, 10, 0.01, Appearance -> "Labeled", 
         ImageSize -> Tiny, ControlPlacement -> 
         3}, {{$CellContext`\[Alpha]d$$, 90, 
          Text[
           Style["Direction \[Alpha] / \[Degree]", 12]]}, 19, 198, 1, 
         Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 4}, 
        Column[{
          Row[{
            Manipulate`Place[1], 
            Spacer[58], 
            Manipulate`Place[2]}], 
          Row[{
            Manipulate`Place[3], 
            Spacer[30], 
            Manipulate`Place[4]}]}]}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{822., {324., 333.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 TextAlignment->Center],

Cell[TextData[{
 StyleBox["References\n[1] Baumann, Rachael L; ",
  FontSize->10],
 StyleBox["Method of Joints to Solve a Truss Problem",
  FontSize->10,
  FontSlant->"Italic"],
 StyleBox[", Retrieved from: \
http://demonstrations.wolfram.com/MethodOfJointsToSolveATrussProblem/",
  FontSize->10]
}], "Text"]
}, Open  ]]
},
WindowSize->{1920, 997},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
Magnification:>1.5 Inherited,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 204, 7, 230, "Title"],
Cell[1693, 44, 2416, 57, 359, "Text"],
Cell[4112, 103, 25847, 604, 681, "Output"],
Cell[29962, 709, 308, 9, 60, "Text"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature Dupy8#ZbWfO6kC18ljl9sucb *)
